@@ -1,5 +1,5 @@
 ##
-#  Copyright (c) 2008-2010 Fred Hutchinson Cancer Research Center
+#  Copyright (c) 2008-2012 Fred Hutchinson Cancer Research Center
 # 
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -32,18 +32,18 @@ if(is.null(containerFilter)==FALSE) {char <- nchar(containerFilter[1]); if(char<
 if(exists("baseUrl")==FALSE || exists("folderPath")==FALSE || exists("schemaName")==FALSE || exists("queryName")==FALSE)
 stop (paste("A value must be specified for each of baseUrl, folderPath, schemaName and queryName."))
 
-## URL encoding of schema, query, view and folder path
-if(length(grep("%",schemaName))<1) {schemaName <- URLencode(schemaName)}
-if(length(grep("%",queryName))<1) {queryName <- URLencode(queryName)}
-if(length(grep("%",folderPath))<1) {folderPath <- URLencode(folderPath)}
-if(is.null(viewName)==FALSE) {if(length(grep("%",viewName))<1) viewName <- URLencode(viewName)}
-if(is.null(containerFilter)==FALSE) {if(length(grep("%",containerFilter))<1) containerFilter<- URLencode(containerFilter)}
+## URL encoding of schema, query, view and folder path (if not already encoded)
+if(schemaName==curlUnescape(schemaName)) {schemaName <- curlEscape(schemaName)}
+if(queryName==curlUnescape(queryName)) {queryName <- curlEscape(queryName)}
+if(folderPath==URLdecode(folderPath)) {folderPath <- URLencode(folderPath)}
+if(is.null(viewName)==FALSE) {if(viewName==curlUnescape(viewName)) viewName <- curlEscape(viewName)}
+if(is.null(containerFilter)==FALSE) {if(containerFilter==curlUnescape(containerFilter)) containerFilter<- curlEscape(containerFilter)}                            
 
 ## Format colSelect
 if(is.null(colSelect)==FALSE)
   {   lencolSel <- length(colSelect)
     holder <- NULL
-      for(i in 1:length(colSelect)) holder <-paste(holder,URLencode(colSelect[i]),",",sep="")
+      for(i in 1:length(colSelect)) holder <-paste(holder,curlEscape(colSelect[i]),",",sep="")
       colSelect <- substr(holder, 1, nchar(holder)-1)}
 
 ## Formatting
